- Add new reftype fringefreq [#846]

11.4.3 (2021-09-30)
===================

- Change JWST validation errors into warnings. [#845]

11.4.2 (2021-09-20)
===================

- Update STIS and ACS IMPHTTAB validations to permit additional
  values in the DATACOL column. [#844]

11.4.1 (2021-09-15)
===================

- Update JWST certifier to show all datamodels validation failures
  instead of stopping at the first. [#842]

- Switch to setuptools_scm for package version management and
  deprecate ``crds.__rationale__`` variable. [#843]
